@@ -3,14 +3,18 @@
 
 from typing import Iterator, Union
 
+from amundsen_rds.models import RDSModel
+from amundsen_rds.models.table import TableTimestamp as RDSTableTimestamp
+
 from databuilder.models.graph_node import GraphNode
 from databuilder.models.graph_relationship import GraphRelationship
 from databuilder.models.graph_serializable import GraphSerializable
 from databuilder.models.table_metadata import TableMetadata
+from databuilder.models.table_serializable import TableSerializable
 from databuilder.models.timestamp import timestamp_constants
 
 
-class TableLastUpdated(GraphSerializable):
+class TableLastUpdated(GraphSerializable, TableSerializable):
     # constants
     LAST_UPDATED_NODE_LABEL = timestamp_constants.NODE_LABEL
     LAST_UPDATED_KEY_FORMAT = '{db}://{cluster}.{schema}/{tbl}/timestamp'
@@ -35,6 +39,7 @@ class TableLastUpdated(GraphSerializable):
 
         self._node_iter = self._create_node_iterator()
         self._relation_iter = self._create_relation_iterator()
+        self._record_iter = self._create_record_iterator()
 
     def __repr__(self) -> str:
         return f"TableLastUpdated(table_name={self.table_name!r}, last_updated_time={self.last_updated_time!r}, " \
@@ -53,6 +58,12 @@ class TableLastUpdated(GraphSerializable):
         except StopIteration:
             return None
 
+    def create_next_record(self) -> Union[RDSModel, None]:
+        try:
+            return next(self._record_iter)
+        except StopIteration:
+            return None
+
     def get_table_model_key(self) -> str:
         # returns formatted string for table name
         return TableMetadata.TABLE_KEY_FORMAT.format(db=self.db,
@@ -98,3 +109,17 @@ class TableLastUpdated(GraphSerializable):
             attributes={}
         )
         yield relationship
+
+    def _create_record_iterator(self) -> Iterator[RDSModel]:
+        """
+        Create a table timestamp record
+        :return:
+        """
+        record = RDSTableTimestamp(
+            rk=self.get_last_updated_model_key(),
+            last_updated_timestamp=self.last_updated_time,
+            timestamp=self.last_updated_time,
+            name=timestamp_constants.TimestampName.last_updated_timestamp.name,
+            table_rk=self.get_table_model_key()
+        )
+        yield record
